<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="sv">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Applikations Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytyp</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adress</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valfri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Koppla från</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Ansluter</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Koppla från</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Trådbunden Anslutning %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Trådlös Anslutning %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Anslutning %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Ny VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN Typ</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportera</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Applikations Proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Nätverksdetaljer</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Trådbundet nätverk</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådlöst nätverk</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Lägg till Nätverksanslutning</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Anslut till dolt nätverk</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Skapa PPPoE anslutning</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Skapa VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importera VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytyp</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adress</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Gränssnitt</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primär DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nätmask</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighet</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhet MAC Addr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonad MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Anpassa MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Lägg till inställningar</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Adress</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nätmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorera</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adress</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Method</source>
        <translation>Metod</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nätmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metod</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorera</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Nätverksdetaljer</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Applikations Proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Nätverksdetaljer</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverad</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Tjänster</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Avböj EAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Avböj PAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Avböj CHAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Avböj MSCHAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Avböj MSCHAPv2 Autentisering</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD Datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen Deflate Datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP Header Compression</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen Protocol Field Compression</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen Address/Control Compression</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Skicka PPP Echo Paket</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Använd MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Skapa PPPoE anslutning</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytyp</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valfri</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurations URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunnlad TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Skyddad EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverad</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonym</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autentiserad</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Båda</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Alternativ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nyckel</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Användarcert</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonymt ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC fil</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Version</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Lösenord</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Nyckel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Säkerhet Obligatorisk</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>Nyckel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avancerad</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Anpassa Gateway Port</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Anpassa Renegotiation Interval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Renegotiation Interval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Använd LZO data kompression</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Använd TCP anslutning</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Använd TAP enhet</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Anpassa Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Anpassa UDP Fragment Size</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Fragment Size</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Begränsa Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Slumpa Fjärrvärdar</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avancerad</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (förval)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Säker (förval)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Svag</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T När Tillgängligt (förval)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Alltid</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverad</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (förval)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (förval)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domän</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Leverantör</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Kryptering</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Läge</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokal Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Inaktivera Dead Peer Detektion</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Aktivera IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppnamn</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Grupp ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Tillåt Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Användarcert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nyckel</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Använd FSID för nyckelns lösenordsfras</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikat (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikat med Lösenord (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statisk Nyckel</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sparad</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Krävs Inte</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Typ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Användarcert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nyckel</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Alternativ</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Lösenord</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Anpassa Nyckelriktning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nyckelriktning</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Fjärr IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokalt IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Allt Tillgängligt (förval)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (minst säker)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (mest säker)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Avböj EAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Avböj PAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Avböj CHAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Avböj MSCHAP Autentisering</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Avböj MSCHAPv2 Autentisering</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD Datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen Deflate Datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP Header Compression</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen Protocol Field Compression</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen Address/Control Compression</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Skicka PPP Echo Paket</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Använd MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Skapa VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importera VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Fel vid Import</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>Okej</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Krävs Inte</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytyp</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Försök på obestämd tid vid misslyckande</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA Fil</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorera Certifikat Varningar</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN Säkerhet</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Förval</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sparad</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Krävs Inte</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Alternativ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domän</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nyckel</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Typ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Användarcert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Använd IP Kompression</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Authentication</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Förval</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subject Match</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Fjärr Cert Type</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Nyckelfil</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Anpassa Nyckelriktning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nyckelriktning</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sparad</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Fråga</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Krävs Inte</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Alternativ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppnamn</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Grupplösenord</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Använd Hybridautentisering</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA Fil</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Sätt i nätverkskabeln först</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Lägg till Nätverksanslutning</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Välj Inställningar</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Stäng Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Anslut till dolt nätverk</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Krävs</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhet MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Anpassa MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>